@@ -10,14 +10,26 @@ class saveAcountKeys:
     self.loaded_addresses = get_loaded_addresses(txnData)
     self.read_only_addresses = get_read_only_addresses(txnData)
     self.writable_addresses = get_writable_addresses(txnData)
-    self.accountKeys = self.get_all_addresses()
+    self.accountKeys = self.get_all_addresses(txnData)
     
   def get_all_addresses(self,txnData=None):
     txnData = txnData or self.txnData
     return get_sorted_addresses(txnData)
     
   def sort_account_keys(self, accountKeys):
-    return sorted(accountKeys, key=lambda x: x['pubkey'].to_base58())    
+    # Extract the necessary components
+    message = txnData['transaction']['message']
+    account_keys = get_all_account_keys(txnData)
+    instructions = message['instructions']
+
+    # Reorder account keys according to the schema
+    signers = [key for key in account_keys if 'signer' in str(key)]
+    writable_non_signers = [key for key in account_keys if 'writable' in str(key) and 'signer' not in str(key)]
+    readonly_non_signers = [key for key in account_keys if 'writable' not in str(key) and 'signer' not in str(key)]
+
+    # Combine in the correct order
+    ordered_account_keys = signers + writable_non_signers + readonly_non_signers
+    return ordered_account_keys   
 
 
   def get_account_from_index(self,index):
